CVS commit: src/sys/arch/x68k/stand

2016-06-25 Thread Tetsuya Isaki
Module Name:src
Committed By:   isaki
Date:   Sun Jun 26 04:17:18 UTC 2016

Modified Files:
src/sys/arch/x68k/stand/boot: boot.c
src/sys/arch/x68k/stand/libsa: devopen.c libx68k.h

Log Message:
Add SCSI host adaptor selector to "boot" command of /boot.
By this function, /boot which booted from non-SCSI
(in other words, floppy) can load SCSI kernel.
Now, single /boot can load kernel of all supported filesystems
of all supported boot devices.

---
New "boot" command's syntax is: boot [hostadaptor@][dev:][file]

If you booted from SCSI, hostadaptor is already set (from IOCS)
and you can omit hostadaptor in this case.  You can type like
"boot sd0a:netbsd" as before.

If you booted from floppy (hostadaptor is not set) and want to
load the SCSI kernel (hostadaptor is needed), you have to select
your hostadaptor in boot command, like "boot spc0@sd0a:netbsd".


To generate a diff of this commit:
cvs rdiff -u -r1.28 -r1.29 src/sys/arch/x68k/stand/boot/boot.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/x68k/stand/libsa/devopen.c \
src/sys/arch/x68k/stand/libsa/libx68k.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x68k/stand/libsa/devopen.c
diff -u src/sys/arch/x68k/stand/libsa/devopen.c:1.6 src/sys/arch/x68k/stand/libsa/devopen.c:1.7
--- 

CVS commit: src/sbin/umount

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sun Jun 26 04:01:30 UTC 2016

Modified Files:
src/sbin/umount: umount.c

Log Message:
Don't assume that getaddrinfo sets the result pointer to null when it
fails. (In fact it probably doesn't...)


To generate a diff of this commit:
cvs rdiff -u -r1.51 -r1.52 src/sbin/umount/umount.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/umount/umount.c
diff -u src/sbin/umount/umount.c:1.51 src/sbin/umount/umount.c:1.52
--- src/sbin/umount/umount.c:1.51	Sun Jun 26 03:51:28 2016
+++ src/sbin/umount/umount.c	Sun Jun 26 04:01:30 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: umount.c,v 1.51 2016/06/26 03:51:28 dholland Exp $	*/
+/*	$NetBSD: umount.c,v 1.52 2016/06/26 04:01:30 dholland Exp $	*/
 
 /*-
  * Copyright (c) 1980, 1989, 1993
@@ -39,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 19
 #if 0
 static char sccsid[] = "@(#)umount.c	8.8 (Berkeley) 5/8/95";
 #else
-__RCSID("$NetBSD: umount.c,v 1.51 2016/06/26 03:51:28 dholland Exp $");
+__RCSID("$NetBSD: umount.c,v 1.52 2016/06/26 04:01:30 dholland Exp $");
 #endif
 #endif /* not lint */
 
@@ -148,7 +148,9 @@ main(int argc, char *argv[])
 
 	if (nfshost != NULL) {
 		memset(, 0, sizeof hints);
-		getaddrinfo(nfshost, NULL, , _ai);
+		if (getaddrinfo(nfshost, NULL, , _ai) != 0) {
+			nfshost_ai = NULL;
+		}
 	}
 		
 	errs = 0;
@@ -252,7 +254,8 @@ umountfs(const char *name, const char **
 memcpy(hostp, name, len);
 hostp[len] = 0;
 name += len + 1;
-getaddrinfo(hostp, NULL, , );
+if (getaddrinfo(hostp, NULL, , ) != 0)
+	ai = NULL;
 			}
 		}
 



CVS commit: src/sbin/umount

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sun Jun 26 03:59:11 UTC 2016

Modified Files:
src/sbin/umount: umount.8

Log Message:
Document external unmount programs. PR 698. Bump date.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sbin/umount/umount.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/umount/umount.8
diff -u src/sbin/umount/umount.8:1.15 src/sbin/umount/umount.8:1.16
--- src/sbin/umount/umount.8:1.15	Sun May 17 14:09:15 2009
+++ src/sbin/umount/umount.8	Sun Jun 26 03:59:11 2016
@@ -1,4 +1,4 @@
-.\"	$NetBSD: umount.8,v 1.15 2009/05/17 14:09:15 mjf Exp $
+.\"	$NetBSD: umount.8,v 1.16 2016/06/26 03:59:11 dholland Exp $
 .\"
 .\" Copyright (c) 1980, 1989, 1991, 1993
 .\"	The Regents of the University of California.  All rights reserved.
@@ -29,7 +29,7 @@
 .\"
 .\" @(#)umount.8	8.2 (Berkeley) 5/8/95
 .\"
-.Dd May 17, 2009
+.Dd June 26, 2016
 .Dt UMOUNT 8
 .Os
 .Sh NAME
@@ -51,7 +51,7 @@ The
 command
 calls the
 .Xr unmount 2
-system call to remove a
+system call (or an external unmount program) to remove a
 .Ar "special device"
 or the remote node (rhost:path) from the filesystem tree at the point
 .Ar node .
@@ -63,6 +63,22 @@ are not provided, the appropriate inform
 .Xr fstab 5
 file.
 .Pp
+By default, the file system type is extracted from the kernel and used
+to choose an external unmount program, whose name is formed by
+appending an underscore and the type string to
+.Dq umount .
+This matches the form used by the external mount programs used by
+.Xr mount 8 .
+If this program is found on the path, it is used in preference to
+calling
+.Xr unmount 2
+directly.
+Note that in the
+.Nx
+base system no such external unmount programs exist; the
+facility is provided in the hopes that it will be useful for third
+party file systems and/or for research.
+.Pp
 The options are as follows:
 .Bl -tag -width indent
 .It Fl a
@@ -97,6 +113,7 @@ and/or
 This is the only way to unmount something that does not appear as a
 directory (such as a nullfs mount of a plain file); there are probably
 other cases where it is necessary.
+This option also disables the use of any external unmount program.
 .It Fl h Ar host
 Only filesystems mounted from the specified host will be
 unmounted.



CVS commit: src/sbin/umount

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sun Jun 26 03:51:28 UTC 2016

Modified Files:
src/sbin/umount: umount.c

Log Message:
Fix previous to avoid using an uninitialized pointer when using -R (raw).


To generate a diff of this commit:
cvs rdiff -u -r1.50 -r1.51 src/sbin/umount/umount.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/umount/umount.c
diff -u src/sbin/umount/umount.c:1.50 src/sbin/umount/umount.c:1.51
--- src/sbin/umount/umount.c:1.50	Sun Jun 26 03:40:39 2016
+++ src/sbin/umount/umount.c	Sun Jun 26 03:51:28 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: umount.c,v 1.50 2016/06/26 03:40:39 dholland Exp $	*/
+/*	$NetBSD: umount.c,v 1.51 2016/06/26 03:51:28 dholland Exp $	*/
 
 /*-
  * Copyright (c) 1980, 1989, 1993
@@ -39,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 19
 #if 0
 static char sccsid[] = "@(#)umount.c	8.8 (Berkeley) 5/8/95";
 #else
-__RCSID("$NetBSD: umount.c,v 1.50 2016/06/26 03:40:39 dholland Exp $");
+__RCSID("$NetBSD: umount.c,v 1.51 2016/06/26 03:51:28 dholland Exp $");
 #endif
 #endif /* not lint */
 
@@ -259,10 +259,9 @@ umountfs(const char *name, const char **
 		if (!namematch(ai))
 			return 1;
 #endif /* ! SMALL */
+		snprintf(umountprog, sizeof(umountprog), "umount_%s", type);
 	}
 
-	snprintf(umountprog, sizeof(umountprog), "umount_%s", type);
-
 #ifndef SMALL
 	if (verbose) {
 		(void)printf("%s: unmount from %s\n", name, mntpt);



CVS commit: src/sbin/umount

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sun Jun 26 03:40:39 UTC 2016

Modified Files:
src/sbin/umount: umount.c

Log Message:
If an external unmount program of the form "umount_TYPE" exists
(e.g. umount_ffs, umount_nfs, etc.) exec it instead of calling
unmount(2).

Closes PR 698.

Note that the original plan for the PR also involved adding a generic
facility to store an alternate FS type name in the kernel to use when
unmounting. This was intended to support filesystems implemented as
loopback nfs servers, where the visible mount would be of type "nfs"
pointing at localhost; in that case one would want to be able to
provide an additional string in order to run an unmount program that
would both remove that mount and also shut down the loopback nfs
server daemon.

However, in the 21+ years since the PR was filed, loopback nfs servers
have gone out of favor (for good reasons) so I don't see any need to
worry about this case at present, especially since the PR has been
hanging around this long anyway. (If anyone still has a loopback nfs
server that they want to use a custom unmount program with, file a new
PR and assign it to me and I'll deal with it specifically in the nfs
mount args structure, which unmount already knows how to retrieve and
examine.)

It is my understanding that filesystems implemented with fuse (which
has displaced the loopback nfs server model) can already set the FS
type field so no further work is needed to allow them to use a custom
unmount program. If this is not the case, please let me know and I'll
attend to it.

There is no longer any need that I see to provide a general facility
for storing an alternate filesystem type name.

(One might also ask whether there's any real need for this
functionality at all any more; this is a fair question, but (a) the
change is small and (b) there are certainly cases when doing FS
research where you want a custom unmount program; been there & done
that.)


To generate a diff of this commit:
cvs rdiff -u -r1.49 -r1.50 src/sbin/umount/umount.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/umount/umount.c
diff -u src/sbin/umount/umount.c:1.49 src/sbin/umount/umount.c:1.50
--- src/sbin/umount/umount.c:1.49	Sun Jun 26 03:05:52 2016
+++ src/sbin/umount/umount.c	Sun Jun 26 03:40:39 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: umount.c,v 1.49 2016/06/26 03:05:52 dholland Exp $	*/
+/*	$NetBSD: umount.c,v 1.50 2016/06/26 03:40:39 dholland Exp $	*/
 
 /*-
  * Copyright (c) 1980, 1989, 1993
@@ -39,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 19
 #if 0
 static char sccsid[] = "@(#)umount.c	8.8 (Berkeley) 5/8/95";
 #else
-__RCSID("$NetBSD: umount.c,v 1.49 2016/06/26 03:05:52 dholland Exp $");
+__RCSID("$NetBSD: umount.c,v 1.50 2016/06/26 03:40:39 dholland Exp $");
 #endif
 #endif /* not lint */
 
@@ -59,6 +59,7 @@ __RCSID("$NetBSD: umount.c,v 1.49 2016/0
 #endif /* !SMALL */
 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -183,7 +184,7 @@ umountfs(const char *name, const char **
 	const char *proto = NULL;
 #endif /* !SMALL */
 	const char *mntpt;
-	char *type, rname[MAXPATHLEN];
+	char *type, rname[MAXPATHLEN], umountprog[MAXPATHLEN];
 	mntwhat what;
 	struct stat sb;
 
@@ -260,13 +261,49 @@ umountfs(const char *name, const char **
 #endif /* ! SMALL */
 	}
 
+	snprintf(umountprog, sizeof(umountprog), "umount_%s", type);
+
 #ifndef SMALL
-	if (verbose)
+	if (verbose) {
 		(void)printf("%s: unmount from %s\n", name, mntpt);
+		/* put this before the test of FAKE */ 
+		if (!raw) {
+			(void)printf("Trying unmount program %s\n",
+			umountprog);
+		}
+	}
 	if (fake)
 		return 0;
 #endif /* ! SMALL */
 
+	if (!raw) {
+		/*
+		 * The only options that need to be passed on are -f
+		 * and -v.
+		 */
+		char *args[3];
+		unsigned nargs = 0;
+
+		args[nargs++] = umountprog;
+		if (fflag == MNT_FORCE) {
+			args[nargs++] = __UNCONST("-f");
+		}
+#ifndef SMALL
+		if (verbose) {
+			args[nargs++] = __UNCONST("-v");
+		}
+#endif
+		execvp(umountprog, args);
+		if (errno != ENOENT) {
+			warn("%s: execvp", umountprog);
+		}
+	}
+
+#ifndef SMALL
+	if (verbose)
+		(void)printf("(No separate unmount program.)\n");
+#endif
+
 	if (unmount(mntpt, fflag) == -1) {
 		warn("%s", mntpt);
 		return 1;



CVS commit: src/sbin/umount

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sun Jun 26 03:05:52 UTC 2016

Modified Files:
src/sbin/umount: umount.c

Log Message:
When SMALL, if realpath() fails, warn() using the failing path instead
of the buffer realpath has declined to write anything into.


To generate a diff of this commit:
cvs rdiff -u -r1.48 -r1.49 src/sbin/umount/umount.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/umount/umount.c
diff -u src/sbin/umount/umount.c:1.48 src/sbin/umount/umount.c:1.49
--- src/sbin/umount/umount.c:1.48	Sat Jun 27 08:29:56 2015
+++ src/sbin/umount/umount.c	Sun Jun 26 03:05:52 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: umount.c,v 1.48 2015/06/27 08:29:56 manu Exp $	*/
+/*	$NetBSD: umount.c,v 1.49 2016/06/26 03:05:52 dholland Exp $	*/
 
 /*-
  * Copyright (c) 1980, 1989, 1993
@@ -39,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 19
 #if 0
 static char sccsid[] = "@(#)umount.c	8.8 (Berkeley) 5/8/95";
 #else
-__RCSID("$NetBSD: umount.c,v 1.48 2015/06/27 08:29:56 manu Exp $");
+__RCSID("$NetBSD: umount.c,v 1.49 2016/06/26 03:05:52 dholland Exp $");
 #endif
 #endif /* not lint */
 
@@ -204,7 +204,7 @@ umountfs(const char *name, const char **
 		}
 #ifdef SMALL
 		else {
- 			warn("%s", rname);
+ 			warn("%s", name);
  			return 1;
 		}
 #endif /* SMALL */



CVS commit: src/games/boggle/boggle

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sat Jun 25 23:15:41 UTC 2016

Modified Files:
src/games/boggle/boggle: bog.h

Log Message:
Double the threshold for crashing out with "too many words".


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/games/boggle/boggle/bog.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/games/boggle/boggle/bog.h
diff -u src/games/boggle/boggle/bog.h:1.3 src/games/boggle/boggle/bog.h:1.4
--- src/games/boggle/boggle/bog.h:1.3	Thu Aug  7 09:37:05 2003
+++ src/games/boggle/boggle/bog.h	Sat Jun 25 23:15:41 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: bog.h,v 1.3 2003/08/07 09:37:05 agc Exp $	*/
+/*	$NetBSD: bog.h,v 1.4 2016/06/25 23:15:41 dholland Exp $	*/
 
 /*-
  * Copyright (c) 1993
@@ -48,10 +48,10 @@
  * The theoretical maximum for MAXWORDLEN is ('a' - 1) == 96
  */
 #define MAXWORDLEN		40	/* Maximum word length */
-#define MAXPWORDS		200	/* Maximum number of player's words */
-#define MAXMWORDS		200	/* Maximum number of machine's words */
-#define MAXPSPACE		2000	/* Space for player's words */
-#define MAXMSPACE		4000	/* Space for machines's words */
+#define MAXPWORDS		400	/* Maximum number of player's words */
+#define MAXMWORDS		400	/* Maximum number of machine's words */
+#define MAXPSPACE		4000	/* Space for player's words */
+#define MAXMSPACE		8000	/* Space for machines's words */
 
 #define MAXCOLS			20
 



CVS commit: src/share/dict

2016-06-25 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Sat Jun 25 22:54:46 UTC 2016

Modified Files:
src/share/dict: web2

Log Message:
+wok


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/share/dict/web2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/dict/web2
diff -u src/share/dict/web2:1.20 src/share/dict/web2:1.21
--- src/share/dict/web2:1.20	Wed Dec  3 15:26:44 2014
+++ src/share/dict/web2	Sat Jun 25 22:54:46 2016
@@ -232155,6 +232155,7 @@ wog
 wogiet
 Wogulian
 woibe
+wok
 wokas
 woke
 wokowi



CVS commit: src

2016-06-25 Thread Maya Rashish
Module Name:src
Committed By:   maya
Date:   Sat Jun 25 18:05:57 UTC 2016

Modified Files:
src/distrib/sets/lists/base: mi
src/distrib/sets/lists/man: mi
src/external/bsd/pkg_install/sbin: Makefile
Removed Files:
src/external/bsd/pkg_install/dist/bpm: bpm.1 bpm.sh.in
src/external/bsd/pkg_install/sbin/bpm: Makefile

Log Message:
Delete bpm(1)
It hasn't worked in a long time.

PR bin/51268


To generate a diff of this commit:
cvs rdiff -u -r1.1128 -r1.1129 src/distrib/sets/lists/base/mi
cvs rdiff -u -r1.1527 -r1.1528 src/distrib/sets/lists/man/mi
cvs rdiff -u -r1.5 -r0 src/external/bsd/pkg_install/dist/bpm/bpm.1
cvs rdiff -u -r1.3 -r0 src/external/bsd/pkg_install/dist/bpm/bpm.sh.in
cvs rdiff -u -r1.3 -r1.4 src/external/bsd/pkg_install/sbin/Makefile
cvs rdiff -u -r1.1 -r0 src/external/bsd/pkg_install/sbin/bpm/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/base/mi
diff -u src/distrib/sets/lists/base/mi:1.1128 src/distrib/sets/lists/base/mi:1.1129
--- src/distrib/sets/lists/base/mi:1.1128	Thu Jun 16 15:17:56 2016
+++ src/distrib/sets/lists/base/mi	Sat Jun 25 18:05:57 2016
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1128 2016/06/16 15:17:56 agc Exp $
+# $NetBSD: mi,v 1.1129 2016/06/25 18:05:57 maya Exp $
 #
 # Note:	Don't delete entries from here - mark them as "obsolete" instead,
 #	unless otherwise stated below.
@@ -1577,7 +1577,7 @@
 ./usr/sbin/bootpefbase-bootserver-bin
 ./usr/sbin/bootpgwbase-bootserver-bin
 ./usr/sbin/bootptestbase-bootserver-bin
-./usr/sbin/bpm	base-pkgutil-bin	crypto
+./usr/sbin/bpm	base-obsolete		obsolete
 ./usr/sbin/btattachbase-sysutil-bin
 ./usr/sbin/btconfigbase-sysutil-bin
 ./usr/sbin/btcontrolbase-obsolete		obsolete

Index: src/distrib/sets/lists/man/mi
diff -u src/distrib/sets/lists/man/mi:1.1527 src/distrib/sets/lists/man/mi:1.1528
--- src/distrib/sets/lists/man/mi:1.1527	Sun Jun 12 18:44:46 2016
+++ src/distrib/sets/lists/man/mi	Sat Jun 25 18:05:57 2016
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1527 2016/06/12 18:44:46 abhinav Exp $
+# $NetBSD: mi,v 1.1528 2016/06/25 18:05:57 maya Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -82,7 +82,7 @@
 ./usr/share/man/cat1/bdes.0			man-crypto-catman	crypto,.cat
 ./usr/share/man/cat1/bg.0			man-util-catman		.cat
 ./usr/share/man/cat1/biff.0			man-mail-catman		.cat
-./usr/share/man/cat1/bpm.0			man-pkgutil-catman	crypto,.cat
+./usr/share/man/cat1/bpm.0			man-obsolete		crypto,.cat,obsolete
 ./usr/share/man/cat1/bthset.0			man-util-catman		.cat
 ./usr/share/man/cat1/btkey.0			man-util-catman		.cat
 ./usr/share/man/cat1/btpin.0			man-util-catman		.cat
@@ -3241,7 +3241,7 @@
 ./usr/share/man/html1/bdes.html			man-crypto-htmlman	crypto,html
 ./usr/share/man/html1/bg.html			man-util-htmlman	html
 ./usr/share/man/html1/biff.html			man-mail-htmlman	html
-./usr/share/man/html1/bpm.html			man-pkgutil-htmlman	crypto,html
+./usr/share/man/html1/bpm.html			man-obsolete		crypto,html,obsolete
 ./usr/share/man/html1/bthset.html		man-util-htmlman	html
 ./usr/share/man/html1/btkey.html		man-util-htmlman	html
 ./usr/share/man/html1/btpin.html		man-util-htmlman	html
@@ -6010,7 +6010,7 @@
 ./usr/share/man/man1/bdes.1			man-crypto-man		crypto,.man
 ./usr/share/man/man1/bg.1			man-util-man		.man
 ./usr/share/man/man1/biff.1			man-mail-man		.man
-./usr/share/man/man1/bpm.1			man-pkgutil-man		crypto,.man
+./usr/share/man/man1/bpm.1			man-obsolete		crypto,.man,obsolete
 ./usr/share/man/man1/bthset.1			man-util-man		.man
 ./usr/share/man/man1/btkey.1			man-util-man		.man
 ./usr/share/man/man1/btpin.1			man-util-man		.man

Index: src/external/bsd/pkg_install/sbin/Makefile
diff -u src/external/bsd/pkg_install/sbin/Makefile:1.3 src/external/bsd/pkg_install/sbin/Makefile:1.4
--- src/external/bsd/pkg_install/sbin/Makefile:1.3	Mon Feb  2 20:47:21 2009
+++ src/external/bsd/pkg_install/sbin/Makefile	Sat Jun 25 18:05:57 2016
@@ -1,6 +1,6 @@
-# $NetBSD: Makefile,v 1.3 2009/02/02 20:47:21 joerg Exp $
+# $NetBSD: Makefile,v 1.4 2016/06/25 18:05:57 maya Exp $
 
-SUBDIR=		bpm pkg_add pkg_admin pkg_create \
+SUBDIR=		pkg_add pkg_admin pkg_create \
 		pkg_delete pkg_info
 
-.include 
\ No newline at end of file
+.include 



CVS commit: src/sys/arch/evbarm/conf

2016-06-25 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Sat Jun 25 17:31:45 UTC 2016

Modified Files:
src/sys/arch/evbarm/conf: TISDP2420

Log Message:
Fix build


To generate a diff of this commit:
cvs rdiff -u -r1.33 -r1.34 src/sys/arch/evbarm/conf/TISDP2420

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/TISDP2420
diff -u src/sys/arch/evbarm/conf/TISDP2420:1.33 src/sys/arch/evbarm/conf/TISDP2420:1.34
--- src/sys/arch/evbarm/conf/TISDP2420:1.33	Fri Aug  7 13:53:28 2015
+++ src/sys/arch/evbarm/conf/TISDP2420	Sat Jun 25 17:31:45 2016
@@ -1,5 +1,5 @@
 #
-#	$NetBSD: TISDP2420,v 1.33 2015/08/07 13:53:28 maxv Exp $
+#	$NetBSD: TISDP2420,v 1.34 2016/06/25 17:31:45 skrll Exp $
 #
 #	TISDP2420 -- TI OMAP 2420 Eval Board Kernel
 #
@@ -136,9 +136,9 @@ makeoptions	DEBUG="-g"	# compile full sy
 makeoptions	COPY_SYMTAB=1
 
 ## USB Debugging options
-options USB_DEBUG
-options OHCI_DEBUG
-options UHUB_DEBUG
+#options USB_DEBUG
+#options OHCI_DEBUG
+#options UHUB_DEBUG
 
 
 # Valid options for BOOT_ARGS:



CVS commit: src/sys/arch/x68k/stand/boot

2016-06-25 Thread Tetsuya Isaki
Module Name:src
Committed By:   isaki
Date:   Sat Jun 25 16:05:43 UTC 2016

Modified Files:
src/sys/arch/x68k/stand/boot: boot.c

Log Message:
Fix my mistake of previous commit.


To generate a diff of this commit:
cvs rdiff -u -r1.27 -r1.28 src/sys/arch/x68k/stand/boot/boot.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x68k/stand/boot/boot.c
diff -u src/sys/arch/x68k/stand/boot/boot.c:1.27 src/sys/arch/x68k/stand/boot/boot.c:1.28
--- src/sys/arch/x68k/stand/boot/boot.c:1.27	Sat Jun 25 14:35:58 2016
+++ src/sys/arch/x68k/stand/boot/boot.c	Sat Jun 25 16:05:43 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: boot.c,v 1.27 2016/06/25 14:35:58 isaki Exp $	*/
+/*	$NetBSD: boot.c,v 1.28 2016/06/25 16:05:43 isaki Exp $	*/
 
 /*
  * Copyright (c) 2001 Minoura Makoto
@@ -157,15 +157,15 @@ doboot(const char *file, int flags)
 	printf("boot device = %x\n", bootdev);
 	if (file[0] == 'n') {
 		printf("if = %d, unit = %d\n",
-		   B_X68K_SCSI_IF(dev),
-		   B_X68K_SCSI_IF_UN(dev));
+		   B_X68K_SCSI_IF(bootdev),
+		   B_X68K_SCSI_IF_UN(bootdev));
 	} else {
 		printf("if = %d, unit = %d, id = %d, lun = %d, part = %c\n",
-		   B_X68K_SCSI_IF(dev),
-		   B_X68K_SCSI_IF_UN(dev),
-		   B_X68K_SCSI_ID(dev),
-		   B_X68K_SCSI_LUN(dev),
-		   B_X68K_SCSI_PART(dev) + 'a');
+		   B_X68K_SCSI_IF(bootdev),
+		   B_X68K_SCSI_IF_UN(bootdev),
+		   B_X68K_SCSI_ID(bootdev),
+		   B_X68K_SCSI_LUN(bootdev),
+		   B_X68K_SCSI_PART(bootdev) + 'a');
 	}
 #endif
 



CVS commit: src/sys/arch/x68k/stand

2016-06-25 Thread Tetsuya Isaki
Module Name:src
Committed By:   isaki
Date:   Sat Jun 25 14:35:59 UTC 2016

Modified Files:
src/sys/arch/x68k/stand/boot: Makefile boot.c conf.c version
src/sys/arch/x68k/stand/boot_ustar: Makefile
src/sys/arch/x68k/stand/netboot: Makefile
Removed Files:
src/sys/arch/x68k/stand/netboot: conf.c version

Log Message:
Unify netboot and boot (into boot).
Now boot becomes to be able to load the NFS kernel and
netboot also becomes to be able to load the local kernel.
The only difference is the default kernel which loads.
I.e., netboot's default is nfs.

Bump boot_ustar's BOOT_MAXSIZE.


To generate a diff of this commit:
cvs rdiff -u -r1.26 -r1.27 src/sys/arch/x68k/stand/boot/Makefile \
src/sys/arch/x68k/stand/boot/boot.c
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/x68k/stand/boot/conf.c
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/x68k/stand/boot/version
cvs rdiff -u -r1.22 -r1.23 src/sys/arch/x68k/stand/boot_ustar/Makefile
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/x68k/stand/netboot/Makefile
cvs rdiff -u -r1.3 -r0 src/sys/arch/x68k/stand/netboot/conf.c
cvs rdiff -u -r1.2 -r0 src/sys/arch/x68k/stand/netboot/version

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x68k/stand/boot/Makefile
diff -u src/sys/arch/x68k/stand/boot/Makefile:1.26 src/sys/arch/x68k/stand/boot/Makefile:1.27
--- src/sys/arch/x68k/stand/boot/Makefile:1.26	Fri Aug  8 15:19:51 2014
+++ src/sys/arch/x68k/stand/boot/Makefile	Sat Jun 25 14:35:58 2016
@@ -1,11 +1,11 @@
-#	$NetBSD: Makefile,v 1.26 2014/08/08 15:19:51 isaki Exp $
+#	$NetBSD: Makefile,v 1.27 2016/06/25 14:35:58 isaki Exp $
 
 NOMAN=		# defined
 
 .include 
 
 BOOT=		Multi-boot
-VERSIONFILE=	${.CURDIR}/version
+VERSIONFILE=	${.CURDIR}/../boot/version
 VERSION!=	${TOOL_AWK} -F: '$$1 ~ /^[0-9.]*$$/ { it = $$1; } \
 			END { print it }' ${VERSIONFILE}
 NEWVERSWHAT=	"${BOOT}"
@@ -13,7 +13,10 @@ NEWVERSWHAT=	"${BOOT}"
 # text address
 TEXT=		006000
 
-PROG=		boot
+# RTC offset for netboot (XXX hardcoded for JST-9)
+RTC_OFFSET=	-540
+
+PROG?=		boot
 BINDIR=		/usr/mdec
 BINMODE=	444
 STRIPFLAG=
@@ -21,10 +24,12 @@ STRIPFLAG=
 BFDNAME=	a.out-m68k-netbsd
 
 SRCS=		srt0.S boot.c conf.c switch.c exec_image.S
+SRCS+=		if_ne.c ne.c dp8390.c
 S=		${.CURDIR}/../../../..
 M=		${.CURDIR}/../..
 COMMONDIR=	$M/stand/common
 .PATH:		${COMMONDIR}
+.PATH:		${.CURDIR}/../boot
 
 SRCS+=		vers.c
 CLEANFILES+=	vers.c
@@ -39,9 +44,11 @@ CPPFLAGS+=	-D_STANDALONE -DHEAP_VARIABLE
 CPPFLAGS+=	-DTEXTADDR="0x${TEXT}" 
 CPPFLAGS+=	-DBOOT=\"${BOOT}\" -DBOOT_VERS=\"${VERSION}\"
 CPPFLAGS+=	-DLIBSA_ENABLE_LS_OP
+CPPFLAGS+=	-DRTC_OFFSET=${RTC_OFFSET}
+CPPFLAGS+=	-DSUPPORT_BOOTP -DSUPPORT_DHCP
 #CPPFLAGS+=	-DDEBUG
 CFLAGS=		-Wno-main -Os -m68020-60
-LINKFLAGS=	-N -static -T ${.CURDIR}/boot.ldscript
+LINKFLAGS=	-N -static -T ${.CURDIR}/../boot/boot.ldscript
 LIBIOCS!=	cd $M/stand/libiocs && ${PRINTOBJDIR}
 LIBSA!=		cd $M/stand/libsa && ${PRINTOBJDIR}
 L=		${LIBSA}/lib
Index: src/sys/arch/x68k/stand/boot/boot.c
diff -u src/sys/arch/x68k/stand/boot/boot.c:1.26 src/sys/arch/x68k/stand/boot/boot.c:1.27
--- src/sys/arch/x68k/stand/boot/boot.c:1.26	Sun Jun 19 09:42:28 2016
+++ src/sys/arch/x68k/stand/boot/boot.c	Sat Jun 25 14:35:58 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: boot.c,v 1.26 2016/06/19 09:42:28 isaki Exp $	*/
+/*	$NetBSD: boot.c,v 1.27 2016/06/25 14:35:58 isaki Exp $	*/
 
 /*
  * Copyright (c) 2001 Minoura Makoto
@@ -32,9 +32,7 @@
 #include 
 #include 
 #include 
-#ifdef NETBOOT
 #include 
-#endif
 #include 
 
 #include "libx68k.h"
@@ -50,38 +48,32 @@
 #define SRAM_MEMSIZE	(*((long*) 0x00ed0008))
 
 char default_kernel[20] =
-#ifndef NETBOOT
-"sd0a:netbsd";
-#else
+#if defined(NETBOOT)
 "nfs:netbsd";
+#else
+"sd0a:netbsd";
 #endif
 int mpu;
-#ifndef NETBOOT
 int hostadaptor;
-#endif
 int console_device = -1;
 
 #ifdef DEBUG
-#ifdef NETBOOT
 int debug = 1;
 #endif
-#endif
 
 static void help(void);
-#ifndef NETBOOT
 static int get_scsi_host_adapter(void);
-#endif
 static void doboot(const char *, int);
 static void boot(char *);
-#ifndef NETBOOT
 static void cmd_ls(char *);
-#endif
 int bootmenu(void);
 void bootmain(int);
 extern int detectmpu(void);
 extern int badbaddr(void *);
 
-#ifndef NETBOOT
+extern struct fs_ops file_system_ustarfs[];
+extern struct fs_ops file_system_nfs[];
+
 /* from boot_ufs/bootmain.c */
 static int
 get_scsi_host_adapter(void)
@@ -104,25 +96,19 @@ get_scsi_host_adapter(void)
 
 	return ha;
 }
-#endif
 
 static void
 help(void)
 {
 	printf("Usage:\n");
 	printf("boot [dev:][file] -[flags]\n");
-#ifndef NETBOOT
 	printf(" dev:   sd, ID=0-7, PART=a-p\n");
 	printf("cda, ID=0-7\n");
 	printf("fda, UNIT=0-3, format is detected.\n");
-#else
-	printf(" dev:   nfs, first probed NE2000 is used.\n");
-#endif
+	printf("nfs, first probed NE2000 is used.\n");
 	printf(" file:  netbsd, netbsd.gz, etc.\n");
 	printf(" flags: abdqsv\n");

CVS commit: src/sys/arch/sparc64/include

2016-06-25 Thread Palle Lyckegaard
Module Name:src
Committed By:   palle
Date:   Sat Jun 25 13:52:04 UTC 2016

Modified Files:
src/sys/arch/sparc64/include: cpu.h

Log Message:
sun4v: fix previous fix - no need to protect "struct inthand" with "#if 
defined(_KERNEL)" + use proper include file name - sparc64/bus_defs.h -> 
machine/bus_defs.h


To generate a diff of this commit:
cvs rdiff -u -r1.121 -r1.122 src/sys/arch/sparc64/include/cpu.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/include/cpu.h
diff -u src/sys/arch/sparc64/include/cpu.h:1.121 src/sys/arch/sparc64/include/cpu.h:1.122
--- src/sys/arch/sparc64/include/cpu.h:1.121	Thu Jun 23 20:32:40 2016
+++ src/sys/arch/sparc64/include/cpu.h	Sat Jun 25 13:52:04 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: cpu.h,v 1.121 2016/06/23 20:32:40 palle Exp $ */
+/*	$NetBSD: cpu.h,v 1.122 2016/06/25 13:52:04 palle Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -68,9 +68,9 @@
 #include 
 #include 
 #if defined(_KERNEL)
+#include 
 #include 
 #include 
-#include 
 #endif
 #ifdef SUN4V
 #include 
@@ -349,7 +349,6 @@ void cpu_signotify(struct lwp *);
  * handler into the list.  The handler is called with its (single)
  * argument, or with a pointer to a clockframe if ih_arg is NULL.
  */
-#if defined(_KERNEL)
 struct intrhand {
 	int			(*ih_fun)(void *);
 	void			*ih_arg;
@@ -370,7 +369,6 @@ struct intrhand {
 	uint32_t		ih_ivec;
 	char			ih_name[32];	/* name for the above */
 };
-#endif
 extern struct intrhand *intrhand[];
 extern struct intrhand *intrlev[MAXINTNUM];
Index: src/sys/arch/x68k/stand/boot/boot.c
diff -u src/sys/arch/x68k/stand/boot/boot.c:1.28 src/sys/arch/x68k/stand/boot/boot.c:1.29
--- src/sys/arch/x68k/stand/boot/boot.c:1.28	Sat Jun 25 16:05:43 2016
+++ src/sys/arch/x68k/stand/boot/boot.c	Sun Jun 26 04:17:17 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: boot.c,v 1.28 2016/06/25 16:05:43 isaki Exp $	*/
+/*	$NetBSD: boot.c,v 1.29 2016/06/26 04:17:17 isaki Exp $	*/
 
 /*
  * Copyright (c) 2001 Minoura Makoto
@@ -78,13 +78,21 @@ extern struct fs_ops file_system_nfs[];
 static int
 get_scsi_host_adapter(void)
 {
+	uint32_t bootinf;
 	char *bootrom;
 	int ha;
 
-	bootrom = (char *) (IOCS_BOOTINF() & 0x00e0);
+	bootinf = IOCS_BOOTINF();
+	if (bootinf < 0xa0) {
+		/* boot from FD */
+		return 0;
+	}
+
+	/* Or, bootinf indicates the boot address */
+	bootrom = (char *)(bootinf & 0x00e0);
 	/*
 	 * bootrom+0x24	"SCSIIN" ... Internal SCSI (spc@0)
 	 *		"SCSIEX" ... External SCSI (spc@1 or mha@0)
 	 */
 	if (*(u_short *)(bootrom + 0x24 + 4) == 0x494e) {	/* "IN" */
 		ha = (X68K_BOOT_SCSIIF_SPC << 4) | 0;
@@ -101,7 +109,8 @@ static void
 help(void)
 {
 	printf("Usage:\n");
-	printf("boot [dev:][file] -[flags]\n");
+	printf("boot [ha@][dev:][file] -[flags]\n");
+	printf(" ha:spc0, spc1, mha0\n");
 	printf(" dev:   sd, ID=0-7, PART=a-p\n");
 	printf("cda, ID=0-7\n");
 	printf("fda, UNIT=0-3, format is detected.\n");
@@ -118,10 +127,12 @@ doboot(const char *file, int flags)
 {
 	u_long		marks[MARK_MAX];
 	int fd;
+	int ha;		/* host adaptor */
 	int dev;	/* device number in devspec[] */
 	int unit;
 	int part;
 	int bootdev;
+	int maj;
 	char *name;
 	short *p;
 	int loadflag;
@@ -129,7 +140,7 @@ doboot(const char *file, int flags)
 
 	printf("Starting %s, flags 0x%x\n", file, flags);
 
-	if (devparse(file, , , , ) != 0) {
+	if (devparse(file, , , , , ) != 0) {
 		printf("XXX: unknown corruption in /boot.\n");
 	}
 
@@ -138,29 +149,40 @@ doboot(const char *file, int flags)
 		printf("dev = %x, unit = %d, name = %s\n",
 		   dev, unit, name);
 	} else {
-		printf("dev = %x, unit = %d, part = %c, name = %s\n",
-		   dev, unit, part + 'a', name);
+		printf("ha = 0x%x, dev = %x, unit = %d, part = %c, name = %s\n",
+		   ha, dev, unit, part + 'a', name);
 	}
 #endif
 
 	if (dev == 3) {		/* netboot */
 		bootdev = X68K_MAKEBOOTDEV(X68K_MAJOR_NE, unit, 0);
-	} else if (dev == 0) {		/* SCSI */
-		bootdev = X68K_MAKESCSIBOOTDEV(X68K_MAJOR_SD,
-	   hostadaptor >> 4,
-	   hostadaptor & 15,
-	   unit & 7, 0, 0);
-	} else {
+	} else if (dev == 2) {		/* FD */
 		bootdev = X68K_MAKEBOOTDEV(X68K_MAJOR_FD, unit & 3, 0);
+	} else {		/* SCSI */
+		if (ha != 0) {
+			hostadaptor = ha;
+		}
+		if (hostadaptor == 0) {
+			printf("host adaptor must be specified.\n");
+			return;
+		}
+
+		maj = (dev == 0) ? X68K_MAJOR_SD : X68K_MAJOR_CD;
+		bootdev = X68K_MAKESCSIBOOTDEV(maj,
+		hostadaptor >> 4,
+		hostadaptor & 15,
+		unit & 7, 0, 0);
 	}
 #ifdef DEBUG
 	printf("boot device = %x\n", bootdev);
 	if (file[0] == 'n') {
-		printf("if = %d, unit = %d\n",
+		printf("type = %x, if = %d, unit = %d\n",
+		   B_TYPE(bootdev),
 		   B_X68K_SCSI_IF(bootdev),
 		   B_X68K_SCSI_IF_UN(bootdev));
 	} else {
-		printf("if = %d, unit = %d, id = %d, lun = %d, part = %c\n",
+		printf("type = %x, if = %d, unit = %d, id = %d, lun = %d, part = %c\n",
+		   B_TYPE(bootdev),
 		   B_X68K_SCSI_IF(bootdev),
 		   B_X68K_SCSI_IF_UN(bootdev),
 		   B_X68K_SCSI_ID(bootdev),
@@ -78,13 +78,21 @@ extern struct fs_ops file_system_nfs[];
 	/*
-	 * bootrom+0x24	"SCSIIN" ... Internal SCSI (spc@0)
-	 *		"SCSIEX" ... External SCSI (spc@1 or mha@0)
+	 * bootrom+0x24	"SCSIIN" ... Internal SCSI (spc0@)
+	 *		"SCSIEX" ... External SCSI (spc1@ or mha0@)
 	 */
 	if (*(u_short *)(bootrom + 0x24 + 4) == 0x494e) {	/* "IN" */
